# GRedis
redis wrapper client




# Type

## GRedisClient

|        方法        |        解释        |
| ------------- | ------------- |
|    client    |        |
|    keys    |        |
|    random_key    |        |
|    random_more_key    |        |


## GBase

|        方法        |        解释        |
| ------------- | ------------- |
|    delete    |        |
|    expire    |        |
|    expire_ts    |        |
|    move    |        |
|    persist    |        |
|    rename    |        |
|    ttl    |        |
|    type    |        |


## GSequence

|        方法        |        解释        |
| ------------- | ------------- |
|    delete    |        |
|    expire    |        |
|    expire_ts    |        |
|    move    |        |
|    persist    |        |
|    rename    |        |
|    ttl    |        |
|    type    |        |


## GZSet

|        方法        |        解释        |
| ------------- | ------------- |
|    clear    |        |
|    count    |        |
|    count_by_score    |        |
|    data    |        |
|    decrby    |        |
|    delete    |        |
|    expire    |        |
|    expire_ts    |        |
|    incrby    |        |
|    members    |        |
|    members_by_score    |        |
|    move    |        |
|    persist    |        |
|    pop    |        |
|    rank    |        |
|    remove_members_by_rank    |        |
|    remove_members_by_score    |        |
|    rename    |        |
|    score    |        |
|    set    |        |
|    ttl    |        |
|    type    |        |


## GList

|        方法        |        解释        |
| ------------- | ------------- |
|    append    |        |
|    blpop    |        |
|    brpop    |        |
|    clear    |        |
|    count    |        |
|    data    |        |
|    delete    |        |
|    expire    |        |
|    expire_ts    |        |
|    extend    |        |
|    get    |        |
|    index    |        |
|    insert    |        |
|    insert_after    |        |
|    insert_before    |        |
|    move    |        |
|    persist    |        |
|    pop    |        |
|    remove    |        |
|    rename    |        |
|    reverse    |        |
|    rpoplpush    |        |
|    sort    |        |
|    ttl    |        |
|    type    |        |


## GSet

|        方法        |        解释        |
| ------------- | ------------- |
|    add    |        |
|    clear    |        |
|    count    |        |
|    data    |        |
|    delete    |        |
|    difference    |        |
|    difference_key    |        |
|    difference_key_update    |        |
|    difference_update    |        |
|    discard    |        |
|    expire    |        |
|    expire_ts    |        |
|    intersection    |        |
|    intersection_key    |        |
|    intersection_key_update    |        |
|    intersection_update    |        |
|    move    |        |
|    persist    |        |
|    rand_member    |        |
|    rand_pop    |        |
|    remove    |        |
|    rename    |        |
|    ttl    |        |
|    type    |        |
|    union    |        |
|    union_key    |        |
|    union_key_update    |        |
|    union_update    |        |


## GDict

|        方法        |        解释        |
| ------------- | ------------- |
|    delete    |        |
|    expire    |        |
|    expire_ts    |        |
|    move    |        |
|    persist    |        |
|    rename    |        |
|    ttl    |        |
|    type    |        |


## GHash

|        方法        |        解释        |
| ------------- | ------------- |
|    clear    |        |
|    count    |        |
|    data    |        |
|    delete    |        |
|    expire    |        |
|    expire_ts    |        |
|    get    |        |
|    has_key    |        |
|    incr    |        |
|    incr_float    |        |
|    items    |        |
|    keys    |        |
|    move    |        |
|    multi_get    |        |
|    multi_set    |        |
|    persist    |        |
|    pop    |        |
|    rename    |        |
|    set    |        |
|    ttl    |        |
|    type    |        |
|    update    |        |
|    values    |        |


## GString

|        方法        |        解释        |
| ------------- | ------------- |
|    append    |        |
|    count    |        |
|    data    |        |
|    decrement_by    |        |
|    delete    |        |
|    expire    |        |
|    expire_ts    |        |
|    increment_by    |        |
|    increment_float_by    |        |
|    move    |        |
|    persist    |        |
|    rename    |        |
|    set    |        |
|    setex    |        |
|    ttl    |        |
|    type    |        |
